multiformats.multicodec
=======================

.. automodule:: multiformats.multicodec

Multicodec
----------

.. autoclass:: multiformats.multicodec.Multicodec
    :members:

exists
------

.. autofunction:: multiformats.multicodec.exists

get
---

.. autofunction:: multiformats.multicodec.get

multicodec
----------

.. autofunction:: multiformats.multicodec.multicodec

register
--------

.. autofunction:: multiformats.multicodec.register

table
-----

.. autofunction:: multiformats.multicodec.table

unregister
----------

.. autofunction:: multiformats.multicodec.unregister

unwrap
------

.. autofunction:: multiformats.multicodec.unwrap

unwrap_raw
----------

.. autofunction:: multiformats.multicodec.unwrap_raw

validate_multicodec
-------------------

.. autofunction:: multiformats.multicodec.validate_multicodec

wrap
----

.. autofunction:: multiformats.multicodec.wrap
